@@ -15,14 +15,16 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Iterable, Mapping, Optional, Union
+from __future__ import annotations
 
-from airflow.models import BaseOperator
-from airflow.providers.sqlite.hooks.sqlite import SqliteHook
-from airflow.utils.decorators import apply_defaults
+import warnings
+from typing import Sequence
+
+from airflow.exceptions import AirflowProviderDeprecationWarning
+from airflow.providers.common.sql.operators.sql import SQLExecuteQueryOperator
 
 
-class SqliteOperator(BaseOperator):
+class SqliteOperator(SQLExecuteQueryOperator):
     """
     Executes sql code in a specific Sqlite database
 
@@ -34,32 +36,20 @@ class SqliteOperator(BaseOperator):
         sql statement, a list of str (sql statements), or reference to a template file.
         Template reference are recognized by str ending in '.sql'
         (templated)
-    :type sql: str or list[str]
     :param sqlite_conn_id: reference to a specific sqlite database
-    :type sqlite_conn_id: str
     :param parameters: (optional) the parameters to render the SQL query with.
-    :type parameters: dict or iterable
     """
 
-    template_fields = ('sql',)
-    template_ext = ('.sql',)
-    ui_color = '#cdaaed'
+    template_fields: Sequence[str] = ("sql",)
+    template_ext: Sequence[str] = (".sql",)
+    template_fields_renderers = {"sql": "sql"}
+    ui_color = "#cdaaed"
 
-    @apply_defaults
-    def __init__(
-        self,
-        *,
-        sql: str,
-        sqlite_conn_id: str = 'sqlite_default',
-        parameters: Optional[Union[Mapping, Iterable]] = None,
-        **kwargs,
-    ) -> None:
-        super().__init__(**kwargs)
-        self.sqlite_conn_id = sqlite_conn_id
-        self.sql = sql
-        self.parameters = parameters or []
-
-    def execute(self, context: Mapping[Any, Any]) -> None:
-        self.log.info('Executing: %s', self.sql)
-        hook = SqliteHook(sqlite_conn_id=self.sqlite_conn_id)
-        hook.run(self.sql, parameters=self.parameters)
+    def __init__(self, *, sqlite_conn_id: str = "sqlite_default", **kwargs) -> None:
+        super().__init__(conn_id=sqlite_conn_id, **kwargs)
+        warnings.warn(
+            """This class is deprecated.
+            Please use `airflow.providers.common.sql.operators.sql.SQLExecuteQueryOperator`.""",
+            AirflowProviderDeprecationWarning,
+            stacklevel=2,
+        )
